@@ -7,13 +7,21 @@ VERFILE="ver.conf"
 BEF="$APP-"
 AFT=".tar.gz"
 
+#Get the newest version in web
 ver=`curl $URLDIR/$VERFILE`
+#Get the current version from self up direction
 ver_local=`pwd | awk -F"/" '{print $NF}'`
 
+if [ '$ver'x = '$ver_local'x ];then
+    echo "WD is the newest version, not need update!"
+    exit
+fi
+
 tempDir="update"
 
 k=0
 
+#Refer to the update.conf get the newest update package from web that could let currect version updated newest 
 curl $URLDIR/update.conf| grep -i "$ver_local" > outfile
 while read LINES
 do
@@ -35,7 +43,8 @@ do
 done < outfile
 
 if [ $k -eq 0 ];then
-	exit
+    echo "No update package to your version!"	
+    exit
 fi
 
 tar -zxvf $TARFILE
